@@ -4,34 +4,37 @@ use flow_impl_derive::FlowImpl;
 use flowcore::{Implementation, RunAgain, RUN_AGAIN};
 
 #[derive(FlowImpl)]
-/// Pass thru a value based on the index of an item in the stream of values
+/// Pass through a value based on the index of an item in the stream of values
 #[derive(Debug)]
 pub struct Index;
 
 impl Implementation for Index {
     fn run(&self, inputs: &[Value]) -> (Option<Value>, RunAgain) {
         let value = inputs[0].clone();
-        let previous_value = inputs[1].clone();
-        let previous_index = inputs[2].as_i64().unwrap();
-        let select_index = inputs[3].as_i64().unwrap();
 
         let mut output_map = serde_json::Map::new();
 
-        let index = previous_index + 1;
+        if let Some(previous_index) = inputs[2].as_i64() {
+            let index = previous_index + 1;
 
-        match select_index {
-            // A 'select_index' value of -1 indicates to output the last value before the null
-            -1 if value.is_null() => {
-                output_map.insert("selected_value".into(), json!(previous_value))
+            // Always output the 'value" and its index
+            output_map.insert("value".into(), json!(value));
+            output_map.insert("index".into(), json!(index));
+
+            if let Some(select_index) = inputs[3].as_i64() {
+                match select_index {
+                    // A 'select_index' value of -1 indicates to output the last value before the null
+                    -1 if value.is_null() => {
+                        let _ = output_map.insert("selected_value".into(), inputs[1].clone());
+                    }
+                    // If 'select_value' is not -1 then see if it matches the current index
+                    _ if select_index == index => {
+                        let _ = output_map.insert("selected_value".into(), value);
+                    }
+                    _ => {}
+                };
             }
-            // If 'select_value' is not -1 then see if it matches the current index
-            _ if select_index == index => output_map.insert("selected_value".into(), json!(value)),
-            _ => None,
-        };
-
-        // Output the 'value" and its index
-        output_map.insert("value".into(), json!(value));
-        output_map.insert("index".into(), json!(index));
+        }
 
         (Some(Value::Object(output_map)), RUN_AGAIN)
     }
@@ -47,7 +50,7 @@ mod test {
 
     #[test]
     fn select_index_0() {
-        let indexor = Index {};
+        let indexer = Index {};
 
         let value = json!(42);
         let previous_value = Value::Null;
@@ -56,7 +59,7 @@ mod test {
 
         let inputs = vec![value, previous_value, previous_index, select_index];
 
-        let (result, _) = indexor.run(&inputs);
+        let (result, _) = indexer.run(&inputs);
 
         let output_map = result.unwrap();
 
@@ -65,7 +68,7 @@ mod test {
 
     #[test]
     fn not_select_index_0() {
-        let indexor = Index {};
+        let indexer = Index {};
 
         let value = json!(42);
         let previous_value = Value::Null;
@@ -74,7 +77,7 @@ mod test {
 
         let inputs = vec![value, previous_value, previous_index, select_index];
 
-        let (result, _) = indexor.run(&inputs);
+        let (result, _) = indexer.run(&inputs);
 
         let output_map = result.unwrap();
 
@@ -83,7 +86,7 @@ mod test {
 
     #[test]
     fn select_index_1() {
-        let indexor = Index {};
+        let indexer = Index {};
 
         let value = json!(42);
         let previous_value = Value::Null;
@@ -92,7 +95,7 @@ mod test {
 
         let inputs = vec![value, previous_value, previous_index, select_index];
 
-        let (result, _) = indexor.run(&inputs);
+        let (result, _) = indexer.run(&inputs);
 
         let output_map = result.unwrap();
 
@@ -101,7 +104,7 @@ mod test {
 
     #[test]
     fn not_select_index_1() {
-        let indexor = Index {};
+        let indexer = Index {};
 
         let value = json!(42);
         let previous_value = Value::Null;
@@ -110,7 +113,7 @@ mod test {
 
         let inputs = vec![value, previous_value, previous_index, select_index];
 
-        let (result, _) = indexor.run(&inputs);
+        let (result, _) = indexer.run(&inputs);
 
         let output_map = result.unwrap();
 
@@ -119,7 +122,7 @@ mod test {
 
     #[test]
     fn select_last() {
-        let indexor = Index {};
+        let indexer = Index {};
 
         let value = Value::Null;
         let previous_value = json!(42);
@@ -128,7 +131,7 @@ mod test {
 
         let inputs = vec![value, previous_value, previous_index, select_index];
 
-        let (result, _) = indexor.run(&inputs);
+        let (result, _) = indexer.run(&inputs);
 
         let output_map = result.unwrap();
 
@@ -137,7 +140,7 @@ mod test {
 
     #[test]
     fn not_select_last() {
-        let indexor = Index {};
+        let indexer = Index {};
 
         let value = json!(43);
         let previous_value = json!(42);
@@ -146,7 +149,7 @@ mod test {
 
         let inputs = vec![value, previous_value, previous_index, select_index];
 
-        let (result, _) = indexor.run(&inputs);
+        let (result, _) = indexer.run(&inputs);
 
         let output_map = result.unwrap();
 
