@@ -1,7 +1,7 @@
 use serde_json::Value;
 
 use flow_impl_derive::FlowImpl;
-use flowcore::{Implementation, RUN_AGAIN, RunAgain};
+use flowcore::{Implementation, RunAgain, RUN_AGAIN};
 
 #[derive(FlowImpl)]
 /// Duplicate the rows of a matrix
@@ -10,13 +10,15 @@ pub struct DuplicateRows;
 
 impl Implementation for DuplicateRows {
     fn run(&self, inputs: &[Value]) -> (Option<Value>, RunAgain) {
-        let matrix = inputs[0].as_array().unwrap();
-        let factor = &inputs[1];
         let mut output_matrix: Vec<Value> = vec![];
 
-        for row in matrix.iter() {
-            for _i in 0..factor.as_i64().unwrap() {
-                output_matrix.push(row.clone());
+        if let Some(factor) = inputs[1].as_i64() {
+            if let Some(matrix) = inputs[0].as_array() {
+                for row in matrix.iter() {
+                    for _i in 0..factor {
+                        output_matrix.push(row.clone());
+                    }
+                }
             }
         }
 
@@ -26,8 +28,8 @@ impl Implementation for DuplicateRows {
 
 #[cfg(test)]
 mod test {
-    use serde_json::{Number, Value};
     use serde_json::json;
+    use serde_json::{Number, Value};
 
     use flowcore::Implementation;
 
