@@ -1,7 +1,7 @@
 use serde_json::{json, Value};
 
 use flow_impl_derive::FlowImpl;
-use flowcore::{Implementation, RUN_AGAIN, RunAgain};
+use flowcore::{Implementation, RunAgain, RUN_AGAIN};
 
 #[derive(FlowImpl)]
 /// Enumerate the elements of an Array
@@ -10,11 +10,12 @@ pub struct Enumerate;
 
 impl Implementation for Enumerate {
     fn run(&self, inputs: &[Value]) -> (Option<Value>, RunAgain) {
-        let array = inputs[0].as_array().unwrap();
         let mut output_array: Vec<(usize, Value)> = vec![];
 
-        for (index, value) in array.iter().enumerate() {
-            output_array.push((index, value.clone()));
+        if let Some(array) = inputs[0].as_array() {
+            for (index, value) in array.iter().enumerate() {
+                output_array.push((index, value.clone()));
+            }
         }
 
         (Some(json!(output_array)), RUN_AGAIN)
@@ -23,8 +24,8 @@ impl Implementation for Enumerate {
 
 #[cfg(test)]
 mod test {
-    use serde_json::{Number, Value};
     use serde_json::json;
+    use serde_json::{Number, Value};
 
     use flowcore::Implementation;
 
