@@ -1,7 +1,7 @@
 use serde_json::{json, Value};
 
 use flow_impl_derive::FlowImpl;
-use flowcore::{Implementation, RUN_AGAIN, RunAgain};
+use flowcore::{Implementation, RunAgain, RUN_AGAIN};
 
 #[derive(FlowImpl)]
 /// Multiply two matrix rows to a product
@@ -10,14 +10,18 @@ pub struct MultiplyRow;
 
 impl Implementation for MultiplyRow {
     fn run(&self, inputs: &[Value]) -> (Option<Value>, RunAgain) {
-        let row0 = inputs[0].as_array().unwrap();
-        let row1 = inputs[1].as_array().unwrap();
-
         let mut product = 0;
-        for index in 0..row0.len() {
-            product += row0[index].as_i64().unwrap() * row1[index].as_i64().unwrap();
+        if let Some(row0) = inputs[0].as_array() {
+            if let Some(row1) = inputs[1].as_array() {
+                for index in 0..row0.len() {
+                    if let Some(row0_entry) = row0[index].as_i64() {
+                        if let Some(row1_entry) = row1[index].as_i64() {
+                            product += row0_entry * row1_entry;
+                        }
+                    }
+                }
+            }
         }
-
         (Some(json!(product)), RUN_AGAIN)
     }
 }
